==> ToolChain_STM32_1.0.42.tar.bz: ToolChain_STM32_1.0.42/ToolChain/install_08_Board_Olimex_H107.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="100_board_olimex_h107"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------
  Dir=`pwd`
  if [ ! -e OK.Docs ]; then #{
    Get_Fails=""
    dir ../../Documentation/Boards

    getFile http://olimex.com/dev/pdf/ARM/ST/ STM32-H107.pdf Board_STM32-H107.pdf ../../Documentation/Boards/

    if [ "$Get_Fails" == "" ]; then
      touch OK.Docs
    else
      echo "$0 - ERROR: missing files: $Get_Fails"
    fi
  fi #}
  echo "installing in $INSTALLPATH ..."

  Name="${INSTALLPATH}" #{
  createExtensionMakefileHead ${Name} #{
  File="../extensions/makefile.${Name}" 
  cat <<END_OF_MAKEFILE >>$File 

  # activate certain parts of source-code
  COMPILE_OPTS += -DEXTENSION_${Name}=1
  COMPILE_OPTS += -DBOARD=$Name
  BOARD=$Name

  # define microcontroller used on board
  STM32F10X_CL  =1
  COMPILE_OPTS += -DUC_DEVICE=STM32F107VCT6
  COMPILE_OPTS += -DUC_PACKAGE_PINS=100

  COMPILE_OPTS += -DRAM_SIZE_K=64
  COMPILE_OPTS += -DRAM_START=0x20000000
  COMPILE_OPTS += -DFLASH_SIZE_K=256
  COMPILE_OPTS += -DFLASH_START=0x08000000

  # Define port pins
  # reference: http://olimex.com/dev/pdf/ARM/ST/STM32-H107-schematic.pdf

  COMPILE_OPTS += -DTTC_LED1=PIN_PC6
  COMPILE_OPTS += -DTTC_LED2=PIN_PC7
  
  COMPILE_OPTS += -DTTC_SWITCH2=PIN_PA0    # press button switch 1 (named WKUP)

  #{ USART1
  COMPILE_OPTS += -DTTC_USART1=USART2
  COMPILE_OPTS += -DTTC_USART1_TX=GPIOA,2
  COMPILE_OPTS += -DTTC_USART1_RX=GPIOA,3
  COMPILE_OPTS += -DTTC_USART1_CK=GPIOA,4
  COMPILE_OPTS += -DTTC_USART1_CTS=GPIOD,3
  COMPILE_OPTS += -DTTC_USART1_RTS=GPIOD,4
  #}USART1
  #{ USART2
  COMPILE_OPTS += -DTTC_USART2=USART3
  COMPILE_OPTS += -DTTC_USART2_TX=GPIOB,10
  COMPILE_OPTS += -DTTC_USART2_RX=GPIOB,11
  COMPILE_OPTS += -DTTC_USART2_CK=GPIOB,12
  COMPILE_OPTS += -DTTC_USART2_CTS=GPIOB,13
  COMPILE_OPTS += -DTTC_USART2_RTS=GPIOB,14
  #}USART2
  #{ SPI1
  COMPILE_OPTS += -DTTC_SPI1=SPI1          # 
  COMPILE_OPTS += -DTTC_SPI1_MOSI=GPIOA,7  # EXT2-25
  COMPILE_OPTS += -DTTC_SPI1_MISO=GPIOA,6  # EXT2-26 
  COMPILE_OPTS += -DTTC_SPI1_SCK=GPIOA,5   # EXT2-27
  COMPILE_OPTS += -DTTC_SPI1_NSS=GPIOA,4   # EXT2-28
  #}SPI1
  #{ SPI2
  COMPILE_OPTS += -DTTC_SPI2=SPI2          # 
  COMPILE_OPTS += -DTTC_SPI2_MOSI=GPIOB,15 # EXT1-27
  COMPILE_OPTS += -DTTC_SPI2_MISO=GPIOB,14 # EXT1-26
  COMPILE_OPTS += -DTTC_SPI2_SCK=GPIOB,13  # EXT1-25
  COMPILE_OPTS += -DTTC_SPI2_NSS=GPIOB,12  # EXT1-24
  #}SPI2


END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "Protoboard H107 from Olimex -> http://olimex.com/dev/stm32-h107.html"
  cat <<END_OF_ACTIVATE >>$File #{

  rm 2>/dev/null \$Dir_ExtensionsActive/makefile.100_board_*
  
  # create links into extensions.active/
  createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET
  
  activate.200_cpu_stm32f10x.sh QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $Name
  #}

#}
  echo "Installed successfully: $INSTALLPATH"

cd ..
rmdir 2>/dev/null $INSTALLPATH
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.45.tar.bz: ToolChain_STM32_1.0.45/ToolChain/install_08_Board_Olimex_H107.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="100_board_olimex_h107"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------
  Dir=`pwd`
  if [ ! -e OK.Docs ]; then #{
    Get_Fails=""
    dir ../../Documentation/Boards

    getFile http://olimex.com/dev/pdf/ARM/ST/ STM32-H107.pdf Board_STM32-H107.pdf ../../Documentation/Boards/

    if [ "$Get_Fails" == "" ]; then
      touch OK.Docs
    else
      echo "$0 - ERROR: missing files: $Get_Fails"
    fi
  fi #}
  echo "installing in $INSTALLPATH ..."

  Name="${INSTALLPATH}" #{
  createExtensionMakefileHead ${Name} #{
  File="../extensions/makefile.${Name}" 
  cat <<END_OF_MAKEFILE >>$File 

  # activate certain parts of source-code
  COMPILE_OPTS += -DEXTENSION_${Name}=1
  COMPILE_OPTS += -DBOARD=$Name
  BOARD=$Name

  # define microcontroller used on board
  STM32F10X_CL  =1
  COMPILE_OPTS += -DUC_DEVICE=STM32F107VCT6
  COMPILE_OPTS += -DUC_PACKAGE_PINS=100

  COMPILE_OPTS += -DRAM_SIZE_K=64
  COMPILE_OPTS += -DRAM_START=0x20000000
  COMPILE_OPTS += -DFLASH_SIZE_K=256
  COMPILE_OPTS += -DFLASH_START=0x08000000

  # Define port pins
  # reference: http://olimex.com/dev/pdf/ARM/ST/STM32-H107-schematic.pdf

  COMPILE_OPTS += -DTTC_LED1=PIN_PC6
  COMPILE_OPTS += -DTTC_LED2=PIN_PC7
  
  COMPILE_OPTS += -DTTC_SWITCH1=PIN_PA0    # press button switch 1 (named WKUP)
  COMPILE_OPTS += -DTTC_SWITCH1_TYPE=tgm_input_floating # -> ttc_gpio_types.h
  COMPILE_OPTS += -DTTC_SWITCH1_LOWACTIVE=0

  #{ USART1
  COMPILE_OPTS += -DTTC_USART1=USART2
  COMPILE_OPTS += -DTTC_USART1_TX=PIN_PA2
  COMPILE_OPTS += -DTTC_USART1_RX=PIN_PA3
  COMPILE_OPTS += -DTTC_USART1_CK=PIN_PA4
  COMPILE_OPTS += -DTTC_USART1_CTS=PIN_PA0
  COMPILE_OPTS += -DTTC_USART1_RTS=PIN_PA1
  #}USART1
  #{ USART2
  COMPILE_OPTS += -DTTC_USART2=USART3
  COMPILE_OPTS += -DTTC_USART2_TX=PIN_PB10
  COMPILE_OPTS += -DTTC_USART2_RX=PIN_PB11
  COMPILE_OPTS += -DTTC_USART2_CK=PIN_PB12
  COMPILE_OPTS += -DTTC_USART2_CTS=PIN_PB13
  COMPILE_OPTS += -DTTC_USART2_RTS=PIN_PB14
  #}USART2
  #{ SPI1
  COMPILE_OPTS += -DTTC_SPI1=SPI1          # 
  COMPILE_OPTS += -DTTC_SPI1_MOSI=PIN_PA7  # EXT2-25
  COMPILE_OPTS += -DTTC_SPI1_MISO=PIN_PA6  # EXT2-26 
  COMPILE_OPTS += -DTTC_SPI1_SCK=PIN_PA5   # EXT2-27
  COMPILE_OPTS += -DTTC_SPI1_NSS=PIN_PA4   # EXT2-28
  #}SPI1
  #{ SPI2
  COMPILE_OPTS += -DTTC_SPI2=SPI2          # 
  COMPILE_OPTS += -DTTC_SPI2_MOSI=PIN_PB15 # EXT1-27
  COMPILE_OPTS += -DTTC_SPI2_MISO=PIN_PB14 # EXT1-26
  COMPILE_OPTS += -DTTC_SPI2_SCK=PIN_PB13  # EXT1-25
  COMPILE_OPTS += -DTTC_SPI2_NSS=PIN_PB12  # EXT1-24
  #}SPI2
  #{ I2C1 - define inter-integrated circuit interface #1
    COMPILE_OPTS += -DTTC_I2C1=I2C1           # internal device being used for this port
    COMPILE_OPTS += -DTTC_I2C1_SDA=PIN_PB7    # EXT1-19
    COMPILE_OPTS += -DTTC_I2C1_SCL=PIN_PB6    # EXT1-18
    COMPILE_OPTS += -DTTC_I2C1_SMBAL=PIN_PB5  # EXT1-17
  #}I2C1
  #{ I2C2 - define inter-integrated circuit interface #2
    COMPILE_OPTS += -DTTC_I2C2=I2C2           # internal device being used for this port
    COMPILE_OPTS += -DTTC_I2C2_SDA=PIN_PB11   # EXT1-23
    COMPILE_OPTS += -DTTC_I2C2_SCL=PIN_PB10   # EXT1-22
    COMPILE_OPTS += -DTTC_I2C2_SMBAL=PIN_PB12 # EXT1-24
  #}I2C2


END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "Protoboard H107 from Olimex -> http://olimex.com/dev/stm32-h107.html"
  cat <<END_OF_ACTIVATE >>$File #{

  rm 2>/dev/null \$Dir_ExtensionsActive/makefile.100_board_*
  
  # create links into extensions.active/
  createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET
  
  activate.200_cpu_stm32f10x.sh QUIET "\$0"

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $Name
  #}

#}
  echo "Installed successfully: $INSTALLPATH"

cd ..
rmdir 2>/dev/null $INSTALLPATH
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
